/*****************************************************************************
File    : PDFChart.h
Author  : Utility Warrior, (c) 2005-2007
Project : PDF Chart Creator (PDFChart) Dynamic Link Library
Purpose : This file provides C prototypes for all DLL functions

Notes  : a) #include this header file at the top of any C code that references
            any of these DLL functions
		 b) Link with PDFChart.lib which provides the necessary linkage to
		    automatically generate the correct DLL call for the function, plus
			it will ensure that the PDFChart.DLL file is loaded when the
			calling application is run (NB there is no need to use LoadLibrary)
		 c) Ensure that PDFChart.DLL is either in the same directory as the
		    calling application or on the system path

Please refer to the accompanying documentation for full details.
******************************************************************************/


#ifndef _PDFChart_h
#define _PDFChart_h

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*****************************************************************************
   This allows the support of multiple versions of a DLL (if and when
   available) so that functions that might only be available in a later version
   can then only be called if the returned version currently being used is one 
   that supports those functions.
   
   Return value: integer value representing the DLL version, a value of 100 is
                 equivalent to version 1.00
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_GetDLLVersion(void);


/*****************************************************************************
Required
******************************************************************************/
extern __declspec(dllimport) void __stdcall PDFC_License(char *code);
/* This is required to remove the "Evaluation Mode" message that is stamped 
   over the top of every page in the output PDF document.   
   
   To purchase a license code please visit the Utility Warrior web site which 
   has the latest information and prices on the licenses that are available. 

   Return value: none 
*/

#define CHART_BAR_VERTICAL		1
#define CHART_BAR_HORIZONTAL	2
#define CHART_PIE_2D			3
#define CHART_LINE_STANDARD		4
#define CHART_LINE_STEPPED		5
#define CHART_LINE_CURVED		6
#define CHART_AREA_STANDARD		7
#define CHART_AREA_STEPPED		8
#define CHART_AREA_CURVED		9
extern __declspec(dllimport) UINT __stdcall PDFC_Chart(UINT type);
/* Specify which chart type is to be generated.

   Return value:
   0 - success
   1 - invalid chart type
*/

extern __declspec(dllimport) UINT __stdcall PDFC_Page(UINT width, UINT height, double red, double green, double blue);
/* Specify page size and background color

   Width and height must be between 100 and 10000 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - width invalid
   2 - height invalid
   3 - red invalid
   4 - green invalid
   5 - blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_PageName(char *name, BOOL bLandscape, double dblRed, double dblGreen, double dblBlue);
/* Specify page size using common name and background color

   name must be one of: A0, A1, A2, A3, A4, A5, B0, B1, B2, B3, B4, B5, Letter, Tabloid, Ledger, Executive, Legal, Folio, Foolscap, Quarto, Statement

   bLandscape swaps rotates the page size

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - name invalid
   2 - red invalid
   3 - green invalid
   4 - blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_DataSet(char *filename);
/* Load in chart data from an external file - either this and/or an appropriate chart
   type datum function must be used in order to define at least one item of data

   Up to 1000 data items can be added.

   Return value:
   0 - success
   1 - no chart type specified
   2 - could not open filename
   3 - maximum number of data items reached
   101...
     - line (101 - 100), ie line 1 contains invalid data
*/

extern __declspec(dllimport) UINT __stdcall PDFC_DataSeparator(char *separator);
/* Set the data separator text that is used to delineate data fields when loading in data 
   from an external file, by default this is a comma

   A maximum of 10 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

#define SORT_ASCENDING		1
#define SORT_DESCENDING		2
extern __declspec(dllimport) UINT __stdcall PDFC_DataSort(UINT field, UINT order);
/* Specify that the data items are to be sorted before being displayed within the chart

   field must be either 1 or 2

   0 - success
   1 - field invalid
   2 - order invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_Log(char *logFilename);
/* Information and error messages are appended to the end of the file specified (with a timestamp)

   Return value:
   0 - success
   1 - invalid logFilename
*/


/*****************************************************************************
Area Chart Specific
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_AreaDatum(char *label, double value);
/* Add an item of area data.

   Up to 1000 data items can be added.

   Return value:
   0 - success
   1 - area chart type not specified
   2 - maximum number of data items already reached
   3 - label invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_Area(double lineRed, double lineGreen, double lineBlue, double lineThickness, double fillRed, double fillGreen, double fillBlue);
/* Specifies how the area under the data points is to be filled.

   Return value:
   0 - success
   1 - invalid lineRed
   2 - invalid lineGreen
   3 - invalid lineBlue
   4 - invalid lineThickness
   5 - invalid fillRed
   6 - invalid fillGreen
   7 - invalid fillBlue
*/


/*****************************************************************************
Line Chart Specific
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_LineDatum(char *label, double value);
/* Add an item of line data.

   Up to 1000 data items can be added.

   Return value:
   0 - success
   1 - line chart type not specified
   2 - maximum number of data items already reached
   3 - label invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_Line(double lineRed, double lineGreen, double lineBlue, double lineThickness);
/* Specifies the line color and thickness that connects all of the data points together.

   Return value:
   0 - success
   1 - invalid lineRed
   2 - invalid lineGreen
   3 - invalid lineBlue
   4 - invalid lineThickness
*/

#define LINE_POINT_STYLE_FILLED_CIRCLE		1
#define LINE_POINT_STYLE_OUTLINE_CIRCLE		2
#define LINE_POINT_STYLE_FILLED_SQUARE		3
#define LINE_POINT_STYLE_OUTLINE_SQUARE		4
#define LINE_POINT_STYLE_CROSS				5
#define LINE_POINT_STYLE_FILLED_DIAMOND		6
#define LINE_POINT_STYLE_OUTLINE_DIAMOND	7
extern __declspec(dllimport) UINT __stdcall PDFC_LineMarker(double markerRed, double markerGreen, double markerBlue, double size, UINT markerStyle, double outlineThickness);
/* Specifies a marker to be displayed on the line at the data point position.

   Return value:
   0 - success
   1 - invalid markerRed
   2 - invalid markerGreen
   3 - invalid markerBlue
   4 - invalid size
   5 - invalid markerStyle
   6 - invalid outlineThickness
*/

/*****************************************************************************
Bar Chart Specific
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_BarDatum(char *label, double value);
/* Add an item of bar data.

   Up to 1000 data items can be added.

   Return value:
   0 - success
   1 - bar chart type not specified
   2 - maximum number of data items already reached
   3 - label invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_BarColor(double fromRed, double fromGreen, double fromBlue, double toRed, double toGreen, double toBlue);
/* Sets a color (range) for a bar

   Up to 50 bar colors can be defined

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - maximum number of bar colors already specified
   2 - from red invalid
   3 - from green invalid
   4 - from blue invalid
   5 - to red invalid
   6 - to green invalid
   7 - to blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_BarSpacing(UINT spacing);
/* Sets the amount of spacing between bars (bar size automatically calculated from this)

   Return value:
   0 - success
   1 - invalid spacing, must be between 0 and 500 inclusive
*/

extern __declspec(dllimport) UINT __stdcall PDFC_BarSize(UINT size);
/* Sets the bar size (bar spacing automatically calculated from this)

   Return value:
   0 - success
   1 - invalid size, must be between 1 and 500 inclusive
*/

#define LABEL_AT_START						1
#define LABEL_AT_END						2
#define LABEL_AT_CENTER						3
#define LABEL_AT_AXES						4
#define LABEL_AT_AXES_AND_START				5
#define LABEL_AT_AXES_AND_END				6
#define LABEL_AT_AXES_AND_CENTER			7
extern __declspec(dllimport) UINT __stdcall PDFC_BarLabel(UINT labelPosition, char *format);
/* Set the position and label style

   Return value:
   0 - success
   1 - label position not valid
   2 - invalid format
*/

extern __declspec(dllimport) UINT __stdcall PDFC_BarBorder(double width, double red, double green, double blue);
/* Set the bar border width and color

   width must be > 0.0 and <= 100.0

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   0 - success
   1 - width invalid
   2 - red invalid
   3 - green invalid
   4 - blue invalid
*/


/*****************************************************************************
Axes and Labels
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_ChartBackground(double fromRed, double fromGreen, double fromBlue, double toRed, double toGreen, double toBlue);
/* Sets the background color (range) for the chart

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - from red invalid
   2 - from green invalid
   3 - from blue invalid
   4 - to red invalid
   5 - to green invalid
   6 - to blue invalid
*/

#define VERTICAL_ALIGNMENT_TOP				1
#define VERTICAL_ALIGNMENT_MIDDLE			2
#define VERTICAL_ALIGNMENT_BOTTOM			3

#define HORIZONTAL_ALIGNMENT_LEFT			1
#define HORIZONTAL_ALIGNMENT_CENTER			2
#define HORIZONTAL_ALIGNMENT_RIGHT			3
extern __declspec(dllimport) UINT __stdcall PDFC_ChartHeading(UINT verticalAlignment, UINT horizontalAlignment);
/* Sets the chart heading position

   vertical alignment must be either top or bottom (NOT middle)

   Return value:
   0 - success
   1 - vertical alignment invalid
   2 - horizontal alignment invalid
*/

#define FONT_ID_COURIER						1
#define FONT_ID_COURIER_BOLD				2
#define FONT_ID_COURIER_BOLDOBLIQUE			3
#define FONT_ID_COURIER_OBLIQUE				4
#define FONT_ID_HELVETICA					5
#define FONT_ID_HELVETICA_BOLD				6
#define FONT_ID_HELVETICA_BOLDOBLIQUE		7
#define FONT_ID_HELVETICA_OBLIQUE			8
#define FONT_ID_TIMES_ROMAN					9
#define FONT_ID_TIMES_BOLD					10
#define FONT_ID_TIMES_ITALIC				11
#define FONT_ID_TIMES_BOLDITALIC			12
#define FONT_ID_SYMBOL						13
#define FONT_ID_ZAPFDINGBATS				14

#define TEXT_STYLE_NORMAL					1
#define TEXT_STYLE_STROKE					2
extern __declspec(dllimport) UINT __stdcall PDFC_HeadingTitle(   UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
extern __declspec(dllimport) UINT __stdcall PDFC_HeadingSubTitle(UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
extern __declspec(dllimport) UINT __stdcall PDFC_AxesLabelX(     UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
extern __declspec(dllimport) UINT __stdcall PDFC_AxesLabelY(     UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
/* Sets the appropriate text style

   size must be between 1 and 300 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   other color is only required if the style is stroke

   Return value:
   0 - success
   1 - invalid size
   2 - invalid font 
   3 - fill red invalid
   4 - fill green invalid
   5 - fill blue invalid
   6 - invalid style
   7 - other red invalid
   8 - other green invalid
   9 - other blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_AxesCaptionX(UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue, UINT horizontalAlignment, char *label);
extern __declspec(dllimport) UINT __stdcall PDFC_AxesCaptionY(UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue, UINT verticalAlignment, char *label);
/* Sets the appropriate axes label style and text

   size must be between 1 and 300 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   other color is only required if the style is stroke

   Return value:
   0 - success
   1 - invalid size
   2 - invalid font 
   3 - fill red invalid
   4 - fill green invalid
   5 - fill blue invalid
   6 - invalid style
   7 - other red invalid
   8 - other green invalid
   9 - other blue invalid
   10 - invalid horizontal/vertical alignment
   11 - label is invalid
*/

#define AXES_LINE_XY		1
#define AXES_LINE_FULL		2
extern __declspec(dllimport) UINT __stdcall PDFC_AxesLine(double width, double red, double green, double blue, UINT format);
/* Sets the width, color and style for the axes boundary lines surrounding the chart area

   width must be between 0.1 and 100.0 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   Return value:
   0 - success
   1 - invalid width
   2 - red invalid
   3 - green invalid
   4 - blue invalid
   5 - invalid line format
*/

#define AXES_SCALE_FROM_ZERO				1
#define AXES_SCALE_UNDER_LOWEST_VALUE		2
#define AXES_SCALE_RANGE					3
#define AXES_SCALE_EITHER_SIDE				4
extern __declspec(dllimport) UINT __stdcall PDFC_AxesScale(UINT scale, double value1, double value2);
/* Sets the width, color and style for the axes boundary lines surrounding the chart area

   if scale is AXES_SCALE_FROM_ZERO then value1 and value2 are not used
   if scale is AXES_SCALE_UNDER_LOWEST_VALUE then value1 is an integer percentage from 0 to 100%, value2 is not used
   if scale is AXES_SCALE_RANGE then the axes range is from value1 to value2

   Return value:
   0 - success
   1 - invalid scale type
   2 - invalid percentage
*/

extern __declspec(dllimport) UINT __stdcall PDFC_AxesDivisions(UINT divisions);
/* Sets the number of divisions in the axes scale

   divisions must be between 1 and 100 inclusive

   Return value:
   0 - success
   1 - invalid divisions
*/

extern __declspec(dllimport) UINT __stdcall PDFC_DecimalPoints(UINT points);
/* Sets the number of decimal points to be displayed with a real number

   points must be between 0 and 9 inclusive

   Return value:
   0 - success
   1 - invalid points
*/

extern __declspec(dllimport) UINT __stdcall PDFC_AxesGridLineStyle(UINT dash, UINT gap, UINT offset);
/* Sets the dashed line style for the grid lines

   all parameters must be between 0 and 100 inclusive

   Return value:
   0 - success
   1 - invalid dash
   2 - invalid gap
   3 - invalid offset
*/

extern __declspec(dllimport) UINT __stdcall PDFC_AxesGridLine(double width, double red, double green, double blue);
/* Sets the width and color of the axes grid lines that are drawn within the chart area

   width must be between 0.1 and 100.0 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   Return value:
   0 - success
   1 - invalid width
   2 - red invalid
   3 - green invalid
   4 - blue invalid
*/

#define AXES_LABEL_Y_POSITION_TO_LEFT		1
#define AXES_LABEL_Y_POSITION_TO_RIGHT		2
extern __declspec(dllimport) UINT __stdcall PDFC_AxesLabelYPosition(UINT position);
/* Controls which side of the chart the Y axis label is displayed

   position must be either AXES_LABEL_Y_POSITION_TO_LEFT or AXES_LABEL_Y_POSITION_TO_RIGHT

   Return value:
   0 - success
   1 - invalid position
*/

extern __declspec(dllimport) UINT __stdcall PDFC_AxesLabelSpacing (UINT nth);
/* Controls the display of the X axis data labels (if the chart type supports this)
   so that it displays every nth label on the axes which is useful if there are a 
   lot of labels to display which would otherwise overwrite each other

   nth must be between 1 and 50 inclusive

   Return value:
   0 - success
   1 - nth is invalid
*/


/*****************************************************************************
Pie Chart Specific
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_PieDatum(char *label, double value);
/* Add an item of pie data.

   Up to 1000 data items can be added.

   Return value:
   0 - success
   1 - pie chart type not specified
   2 - maximum number of data items already reached
   3 - label invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_PieColor(double red, double green, double blue);
/* Sets a color for a pie segment

   Up to 50 bar colors can be defined

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - maximum number of pie colors already specified
   2 - red invalid
   3 - green invalid
   4 - blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_PieOutline(double borderWidth, double red, double green, double blue);
/* Sets a color for a pie segment

   borderWidth must be between 0.0 and 100.0 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.

   Return value:
   0 - success
   1 - border width invalid
   2 - red invalid
   3 - green invalid
   4 - blue invalid
*/

extern __declspec(dllimport) UINT __stdcall PDFC_PiePageMargin(double marginSize);
/* Sets the minimum spacing between the edge of the page and the chart

   margin size must be between 0.0 and 100.0 inclusive

   Return value:
   0 - success
   1 - margin size invalid
*/

#define LABEL_INSIDE						8
#define LABEL_OUTSIDE						9
#define LABEL_SPOKE							10
extern __declspec(dllimport) UINT __stdcall PDFC_PieLabel(UINT labelPosition, char *format, UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
/* Sets the label text style

   size must be between 1 and 300 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   other color is only required if the style is stroke

   Return value:
   0 - success
   1 - invalid size
   2 - invalid font 
   3 - fill red invalid
   4 - fill green invalid
   5 - fill blue invalid
   6 - invalid style
   7 - other red invalid
   8 - other green invalid
   9 - other blue invalid
   10 - invalid label format
   11 - invalid label position
*/


/*****************************************************************************
Legends
******************************************************************************/
#define LEGEND_NONE							0
#define LEGEND_ABOVE						1
#define LEGEND_BELOW						2
#define LEGEND_LEFT							3
#define LEGEND_RIGHT						4
extern __declspec(dllimport) UINT __stdcall PDFC_Legend(UINT legendPosition, char *format, double outlineRed, double outlineGreen, double outlineBlue, double outlineWidth, double backgroundRed, double backgroundGreen, double backgroundBlue, UINT size, UINT fontID, double fillRed, double fillGreen, double fillBlue, UINT style, double otherRed, double otherGreen, double otherBlue);
/* Legend box settings

   size must be between 1 and 300 inclusive

   Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive

   other color is only required if the style is stroke

   Return value:
   0 - success
   1 - legend position invalid
   2 - outline red invalid
   3 - outline green invalid
   4 - outline blue invalid
   5 - invalid outline width
   6 - background red invalid
   7 - background green invalid
   8 - background blue invalid
   9 - invalid legend format
   10 - invalid size
   11 - invalid font 
   12 - fill red invalid
   13 - fill green invalid
   14 - fill blue invalid
   15 - invalid style
   16 - other red invalid
   17 - other green invalid
   18 - other blue invalid
*/


/*****************************************************************************
Numerical Analyses
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_LineOfBestFit(double lineRed, double lineGreen, double lineBlue, double lineThickness);
/* Specifies the line thickness and color that is used to display the "line of best fit".

   Return value:
   0 - success
   1 - invalid lineRed
   2 - invalid lineGreen
   3 - invalid lineBlue
   4 - invalid lineThickness
*/


extern __declspec(dllimport) UINT __stdcall PDFC_MovingAverageLine(UINT samplePoints, double lineRed, double lineGreen, double lineBlue, double lineThickness);
/* The moving average at any given point is the average of that point and the preceeding <samplePoints - 1> data items.
   This means that the first moving average point that can be plotted is not at the first position on the chart but at the <samplePoints> position.

   Return value:
   0 - success
   1 - invalid lineRed
   2 - invalid lineGreen
   3 - invalid lineBlue
   4 - invalid lineThickness
   5 - invalid samples
*/


// Following values already defined above
// LINE_POINT_STYLE_FILLED_CIRCLE
// LINE_POINT_STYLE_OUTLINE_CIRCLE
// LINE_POINT_STYLE_FILLED_SQUARE
// LINE_POINT_STYLE_OUTLINE_SQUARE
// LINE_POINT_STYLE_CROSS
// LINE_POINT_STYLE_FILLED_DIAMOND
// LINE_POINT_STYLE_OUTLINE_DIAMOND
extern __declspec(dllimport) UINT __stdcall PDFC_MovingAverageLineMarker(UINT markerStyle, double markerRed, double markerGreen, double markerBlue, double markerSize, double outlineThickness);
/* This is optional and specifies a marker to be displayed on the moving average line at the data point position.

   Return value:
   0 - success
   1 - invalid markerStyle
   2 - invalid markerRed
   3 - invalid markerGreen
   4 - invalid markerBlue
   5 - invalid markerSize
   6 - invalid outlineThickness
*/


/*****************************************************************************
PDF Settings
******************************************************************************/
#define PDF_PERMISSION_READ_ONLY    0
#define PDF_PERMISSION_EDIT			1 
#define PDF_PERMISSION_EDIT_EXTRA   2
#define PDF_PERMISSION_COPY         4
#define PDF_PERMISSION_PRINT        8
extern __declspec(dllimport) int __stdcall PDFC_SetPermissions(int iPermissions);
/* Allows the setting of any combination of permissions in one go

   Return value:
   0 - success
   1 - invalid permissions
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPermissionEdit(void);
/* Allows editing/changing of the PDF document but NOT adding or changing of text 
   notes and AcroForm fields.

   Return value: none 
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPermissionEditExtra(void);
/* Allows the adding and changing of text notes and AcroForm fields within a PDF document.

   Return value: none 
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPermissionCopy(void);
/* Allows the copying of text and graphics from the PDF document.

   Return value: none 
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPermissionPrint(void);
/* Allows printing of the PDF document.

   Return value: none 
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetOwnerPassword(char *password);
/* The owner of a PDF document would enter this password in order to view it
   and make changes and perform actions that may be restricted to a normal user.

   A maximum of 32 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetUserPassword(char *password);
/* In order that only the intended user can view the PDF document, they must type
   in this password, otherwise the user is not allowed to read the PDF document.

   A maximum of 32 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/


/*****************************************************************************
PDF Meta Information
******************************************************************************/
extern __declspec(dllimport) UINT __stdcall PDFC_SetProducer(char *producer);
/* The name of the application that converted the document from its native format to PDF.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetCreator(char *creator);
/* If the document was converted into a PDF document from another form, this is 
   usually the name of the application that created the original document.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetAuthor(char *author);
/* The name of the person who created the PDF document.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetTitle(char *title);
/* The PDF document's title.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetSubject(char *subject);
/* The PDF document's subject.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) UINT __stdcall PDFC_SetKeywords(char *keywords);
/* A list of keywords associated with the PDF document.

   A maximum of 256 characters can be used.

   Return value:
   0 - success
   1 - invalid parameter
*/

extern __declspec(dllimport) void __stdcall PDFC_SetCreationDate(void);
/* The date that the PDF document was created.

   This is set using the current local time of the PC.

   Return value: none
*/


/*****************************************************************************
PDF Viewer Preferences
******************************************************************************/
extern __declspec(dllimport) void __stdcall PDFC_SetViewerPreferenceCenterWindow(void);
/* The window displaying the PDF document should be displayed in the center of 
   the computer's screen.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetViewerPreferenceHideToolbar(void);
/* The PDF viewer's toolbar should be hidden when the PDF document is active.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetViewerPreferenceHideMenubar(void);
/* The PDF viewer's menubar should be hidden when the PDF document is active.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetViewerPreferenceHideWindowUI(void);
/* The user interface elements within the PDF document's window should be hidden.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetViewerPreferenceFitWindow(void);
/* The PDF viewer should resize the window displaying the PDF document to fit the 
   size of the first displayed page of the PDF document.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageModeOutlines(void);
/* The PDF viewer should show the outline (ie bookmark) navigation item when the 
   PDF document is open.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageModeNone(void);
/* The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
   items when the PDF document is open.

   This is the default if no other page mode is specified.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageModeUseThumbs(void);
/* The PDF viewer should show the thumbnail navigation item when the PDF document 
   is open.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageModeFullScreen(void);
/* The PDF viewer should open the PDF document in full-screen mode without showing 
   the menu bar, window controls or any other window.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageLayoutSinglePage(void);
/* Display the pages one page at a time.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageLayoutOneColumn(void);
/* Display the pages in one column.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageLayoutTwoColumnLeft(void);
/* Display the pages in two columns, with odd-numbered pages on the left.

   Return value: none
*/

extern __declspec(dllimport) void __stdcall PDFC_SetPageLayoutTwoColumnRight(void);
/* Display the pages in two columns, with odd-numbered pages on the right.

   Return value: none
*/


/*****************************************************************************
Specifies the name and location of the produced PDF document, 
******************************************************************************/
#define OPTION_NONE			0
#define OPTION_OPEN_PDF		1
#define OPTION_RESET		2
extern __declspec(dllimport) UINT __stdcall PDFC_MakePDF(char *output, int options, char *errorText, UINT maxErrorTextSize);
/* Generate the output PDF according to the settings already selected through
   the Application Programming Interface functions above.

   To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
   bit flag in the options parameter.

   To have all settings applied reset after PDF has been generated set the OPTION_RESET
   bit flag in the options parameter.

   Return value:
   0 - success
   1 - internal error - see errorText for details (unless NULL passed)
   2 - output pdf could not be opened
   3 - chart type not specified
   4 - chart style not specified
   5 - no data items to chart
   6 - no output pdf filename specified
   7 - no bar colors specified
   8 - no pie colors specified
*/

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
